.. _about:


About Us
========

Institutes
----------

| **ETH Zürich,** Signal and Information Processing Laboratory (ISI), ETH Zürich, Prof. Hans-Andrea Loeliger
| **FHNW Muttenz,**  University of Applied Sciences and Arts Northwestern Switzerland, Institute for Medical Engineering and Medical Informatics
| **BFH Biel,** Bern University of Applied Sciences, Institute for Human Centered Engineering



Software Authors
----------------

- Reto Wildhaber, FHNW Muttenz, / ETH Zürich 
- Frédéric Waldmann, FHNW Muttenz, 
- Luca Fleischmann, BFH Biel


Research
--------

- Reto Wildhaber, FHNW Muttenz / ETH Zürich 
- Nour Zalmai, ETH Zürich
- Frédéric Waldmann, FHNW Muttenz

The research was further directly influenced or supported by

- Christoph Reller, ETH Zürich
- Federico Wadehn, ETH Zürich
- Hampus Malmberg, ETH Zürich
- Keusch Raphael, ETH Zürich
- Elizabeth Ren, ETH Zürich


Contact
-------

Reto Wildhaber, FHNW Muttenz / ETH Zürich, Switzerland, reto.wildhaber@fhnw.ch
